@@ -5,17 +5,17 @@ import tensorflow_hub as hub
 import tensorflow_text as text
 import pandas as pd
 import gdown
+import yfinance as yf
+import datetime
+from fbprophet import Prophet
 from sklearn import model_selection, metrics
 
-
 def get_data(path):
 
-    df = pd.read_csv(path, header = None)
-    df.columns = ['label', 'text']
-    c = len(set(df['label'].values))
-    
-    return df, c
-
+	df = pd.read_csv(path, header = None)
+	df.columns = ['label', 'text']
+	c = len(set(df['label'].values))
+	return df, c
 
 def classifier_model(preprocess_layer, encoder_layer, c):
     
@@ -30,10 +30,8 @@ def classifier_model(preprocess_layer, encoder_layer, c):
     x = tf.keras.layers.Dropout(0.5)(x)
     softmax_output = tf.keras.layers.Dense(c, activation='softmax')(x)
     model = tf.keras.Model(text_input, softmax_output)
-    
     return model
 
-
 def load_classifier_model():
     
     url = 'https://drive.google.com/uc?id=1CFk7Zh6qbh6t48_eU0L1bcxnva81TQE5'
@@ -45,8 +43,7 @@ def load_classifier_model():
 def predict_single_sentiment(loaded_model):
 	
     input_text = input()
-    preds = loaded_model.predict([input_text])
-    
+    preds = loaded_model.predict([input_text])    
     label_dict = {0:"neutral", 1:"negative", 2:"positive"}
     return label_dict[np.argmax(preds)], np.max(preds)
 
@@ -54,3 +51,28 @@ def predict_batch_sentiment(loaded_model, sentences):
 
     preds = loaded_model.predict(sentences)
     return sentences, preds
+
+def get_stock_predictions(stock, days_to_get, value_to_get):
+	
+	now = datetime.datetime.today()
+	date = now.strftime("%Y-%m-%d")
+	delta = datetime.timedelta(days=120)
+	start = now - delta
+	start = start.strftime("%Y-%m-%d")
+	data = yf.download(stock, start=start, end=date)
+
+	data['ds'] = data.index
+	data['y'] = data[value_to_get]
+	df = data[['ds', 'y']]
+
+	print("Modeling the data using Prophet")
+	model = Prophet(seasonality_mode="multiplicative", daily_seasonality=True)
+	model.fit(df)
+	future = model.make_future_dataframe(periods=days_to_get)
+	print("Making predictions")
+	forecast = model.predict(future)
+
+	return forecast[['ds', 'yhat']]
+
+
+
